@@ -50,11 +50,31 @@ class PARAMETERS(str, Enum, metaclass=__PARAMETERSMETA):
     FACE_DETECT_MAX_OUT_IMAGE_SIZE = "face_detect_max_out_image_size"
     SEND_ORIGINAL_IMAGES = "send_original_images"
 
+    # BILLING PARAMETERS
+    # ISVALID_RESERVATION_CALLS = "is_valid"
+    # PREDICT_RESERVATION_CALLS = "predict"
+    DOC_FRONT_RESERVATION_CALLS = "document_model"
+    DOC_BACK_RESERVATION_CALLS = "document_model"
+    COMPARE_RESERVATION_CALLS = "compare_files"
+    FACE_RESERVATION_CALLS = "faces"
+    ESTIMATE_AGE_RESERVATION_CALLS = "estimate_age"
+    FACE_ISO_RESERVATION_CALLS = "face_iso"
+
 
 class ParameterValidator:
     def __init__(self):
         self.__parameter = {}
         self.__populate_parameters()
+        self.__billing_reservation_parameters = [
+            # PARAMETERS.PREDICT_RESERVATION_CALLS,
+            # PARAMETERS.ISVALID_RESERVATION_CALLS,
+            PARAMETERS.DOC_FRONT_RESERVATION_CALLS,
+            PARAMETERS.DOC_BACK_RESERVATION_CALLS,
+            PARAMETERS.COMPARE_RESERVATION_CALLS,
+            PARAMETERS.FACE_RESERVATION_CALLS,
+            PARAMETERS.ESTIMATE_AGE_RESERVATION_CALLS,
+            PARAMETERS.FACE_ISO_RESERVATION_CALLS,
+        ]
 
     def __populate_parameters(self):
         self.__parameter[PARAMETERS.INPUT_IMAGE_FORMAT] = self.Parameter(
@@ -138,9 +158,36 @@ class ParameterValidator:
         self.__parameter[PARAMETERS.SEND_ORIGINAL_IMAGES] = self.Parameter(
             name=PARAMETERS.SEND_ORIGINAL_IMAGES, _type="BOOL")
 
+        # BILLING PARAMETERS
+        # self.__parameter[PARAMETERS.ISVALID_RESERVATION_CALLS] = self.Parameter(
+        #     name=PARAMETERS.ISVALID_RESERVATION_CALLS, _type="NUMBER", min_value=0, max_value=100000000)
+        # self.__parameter[PARAMETERS.PREDICT_RESERVATION_CALLS] = self.Parameter(
+        #     name=PARAMETERS.PREDICT_RESERVATION_CALLS, _type="NUMBER", min_value=0, max_value=100000000)
+
+        self.__parameter[PARAMETERS.DOC_FRONT_RESERVATION_CALLS] = self.Parameter(
+            name=PARAMETERS.DOC_FRONT_RESERVATION_CALLS, _type="NUMBER", min_value=0, max_value=100000000)
+
+        self.__parameter[PARAMETERS.DOC_BACK_RESERVATION_CALLS] = self.Parameter(
+            name=PARAMETERS.DOC_BACK_RESERVATION_CALLS, _type="NUMBER", min_value=0, max_value=100000000)
+
+        self.__parameter[PARAMETERS.COMPARE_RESERVATION_CALLS] = self.Parameter(
+            name=PARAMETERS.COMPARE_RESERVATION_CALLS, _type="NUMBER", min_value=0, max_value=100000000)
+
+        self.__parameter[PARAMETERS.FACE_RESERVATION_CALLS] = self.Parameter(
+            name=PARAMETERS.FACE_RESERVATION_CALLS, _type="NUMBER", min_value=0, max_value=100000000)
+
+        self.__parameter[PARAMETERS.ESTIMATE_AGE_RESERVATION_CALLS] = self.Parameter(
+            name=PARAMETERS.ESTIMATE_AGE_RESERVATION_CALLS, _type="NUMBER", min_value=0, max_value=100000000)
+
+        self.__parameter[PARAMETERS.FACE_ISO_RESERVATION_CALLS] = self.Parameter(
+            name=PARAMETERS.FACE_ISO_RESERVATION_CALLS, _type="NUMBER", min_value=0, max_value=100000000)
+
     def validate(self, key, value):
         return self.__parameter[key].validate(value)
 
+    def is_billing_parameter(self, key):
+        return key in self.__billing_reservation_parameters
+
     class Parameter:
         def __init__(self, name=None, _type=None, min_value=None, max_value=None, valid_set=None):
             self.__name = name
@@ -212,9 +259,25 @@ class ConfigObject:
             return None
         config_param_dict = {}
         for key, value in self._config_param.items():
-            config_param_dict[key.value] = value
+            if not self._validate_parameter.is_billing_parameter(key):
+                config_param_dict[key.value] = value
+
+        if len(config_param_dict) == 0:
+            return None
         return json.dumps(config_param_dict)
 
+    def get_config_billing_param(self):
+        if len(self._config_param) == 0:
+            return None
+        config_billing_param = {}
+        for key, value in self._config_param.items():
+            if self._validate_parameter.is_billing_parameter(key):
+                config_billing_param[key.value] = value
+
+        if len(config_billing_param) == 0:
+            return None
+        return json.dumps(config_billing_param)
+
     def __str__(self):
         config_string = ""
         for key, value in self._config_param.items():
